@@ -33,6 +33,8 @@ def process_json(data, entity):
     Args:
         data: row data json
     Returns: list
+    :param data:
+    :param entity:
     """
     return data["_embedded"][entity]
 
@@ -120,7 +122,7 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
                 count_uploaded = len(process_json(objects.json(), self.entity))
                 self.rows_to_upload += count_uploaded
                 self.logger.info(
-                    "Saving data in the file %s, a number of rows %d, total number: %d",
+                    "Saving data to the file %s, a number of rows %d, total number: %d",
                     file_path,
                     count_uploaded,
                     self.rows_to_upload,
