@@ -194,7 +194,7 @@ class AmocrmRunner:
             from amocrm.db.vertica_uploader import UploaderDB
         elif db == "ch":
             from amocrm.db.clickhouse_uploader import UploaderDB
-            if self.date_modified_from is not None:
+            if self.date_modified_from is None:
                 args['full_copy'] = True
 
             args["table_to_optimize"] = self.table_to_optimize
